@@ -3,7 +3,7 @@
  *  See the file "license.terms" for information on usage and redistribution
  *  of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- *     $Id: esdl_glext.h,v 1.4 2003/08/29 13:31:47 dgud Exp $
+ *     $Id: esdl_glext.h,v 1.2 2004/03/31 14:00:15 dgud Exp $
  *
  */
 
@@ -282,7 +282,7 @@ typedef void (APIENTRY * ESDLGLCOMPRESSEDTEXSUBIMAGE1DPROC)(GLenum target, GLint
 ESDL_EXTERN ESDLGLCOMPRESSEDTEXSUBIMAGE1DPROC esdl_glCompressedTexSubImage1D;
 void egl_compressedTexSubImage1D (sdl_data *, int, char *); 
 enum { glGetCompressedTexImageFunc = OPENGL_EXTS_H + 67 };
-typedef void (APIENTRY * ESDLGLGETCOMPRESSEDTEXIMAGEPROC)(GLenum target, GLint level, void * img);
+typedef void (APIENTRY * ESDLGLGETCOMPRESSEDTEXIMAGEPROC)(GLenum target, GLint level, GLvoid * img);
 ESDL_EXTERN ESDLGLGETCOMPRESSEDTEXIMAGEPROC esdl_glGetCompressedTexImage;
 void egl_getCompressedTexImage (sdl_data *, int, char *); 
 enum { glBlendFuncSeparateFunc = OPENGL_EXTS_H + 68 };
@@ -397,247 +397,463 @@ enum { glWindowPos3svFunc = OPENGL_EXTS_H + 95 };
 typedef void (APIENTRY * ESDLGLWINDOWPOS3SVPROC)( const GLshort * v);
 ESDL_EXTERN ESDLGLWINDOWPOS3SVPROC esdl_glWindowPos3sv;
 void egl_windowPos3sv (sdl_data *, int, char *); 
-enum { glWeightbvARBFunc = OPENGL_EXTS_H + 96 };
+enum { glGenQueriesFunc = OPENGL_EXTS_H + 96 };
+typedef void (APIENTRY * ESDLGLGENQUERIESPROC)(GLsizei n, GLuint * ids);
+ESDL_EXTERN ESDLGLGENQUERIESPROC esdl_glGenQueries;
+void egl_genQueries (sdl_data *, int, char *); 
+enum { glDeleteQueriesFunc = OPENGL_EXTS_H + 97 };
+typedef void (APIENTRY * ESDLGLDELETEQUERIESPROC)(GLsizei n,  const GLuint * ids);
+ESDL_EXTERN ESDLGLDELETEQUERIESPROC esdl_glDeleteQueries;
+void egl_deleteQueries (sdl_data *, int, char *); 
+enum { glIsQueryFunc = OPENGL_EXTS_H + 98 };
+typedef GLboolean (APIENTRY * ESDLGLISQUERYPROC)(GLuint id);
+ESDL_EXTERN ESDLGLISQUERYPROC esdl_glIsQuery;
+void egl_isQuery (sdl_data *, int, char *); 
+enum { glBeginQueryFunc = OPENGL_EXTS_H + 99 };
+typedef void (APIENTRY * ESDLGLBEGINQUERYPROC)(GLenum target, GLuint id);
+ESDL_EXTERN ESDLGLBEGINQUERYPROC esdl_glBeginQuery;
+void egl_beginQuery (sdl_data *, int, char *); 
+enum { glEndQueryFunc = OPENGL_EXTS_H + 100 };
+typedef void (APIENTRY * ESDLGLENDQUERYPROC)(GLenum target);
+ESDL_EXTERN ESDLGLENDQUERYPROC esdl_glEndQuery;
+void egl_endQuery (sdl_data *, int, char *); 
+enum { glGetQueryivFunc = OPENGL_EXTS_H + 101 };
+typedef void (APIENTRY * ESDLGLGETQUERYIVPROC)(GLenum target, GLenum pname, GLint * params);
+ESDL_EXTERN ESDLGLGETQUERYIVPROC esdl_glGetQueryiv;
+void egl_getQueryiv (sdl_data *, int, char *); 
+enum { glGetQueryObjectivFunc = OPENGL_EXTS_H + 102 };
+typedef void (APIENTRY * ESDLGLGETQUERYOBJECTIVPROC)(GLuint id, GLenum pname, GLint * params);
+ESDL_EXTERN ESDLGLGETQUERYOBJECTIVPROC esdl_glGetQueryObjectiv;
+void egl_getQueryObjectiv (sdl_data *, int, char *); 
+enum { glGetQueryObjectuivFunc = OPENGL_EXTS_H + 103 };
+typedef void (APIENTRY * ESDLGLGETQUERYOBJECTUIVPROC)(GLuint id, GLenum pname, GLuint * params);
+ESDL_EXTERN ESDLGLGETQUERYOBJECTUIVPROC esdl_glGetQueryObjectuiv;
+void egl_getQueryObjectuiv (sdl_data *, int, char *); 
+enum { glBindBufferFunc = OPENGL_EXTS_H + 104 };
+typedef void (APIENTRY * ESDLGLBINDBUFFERPROC)(GLenum target, GLuint buffer);
+ESDL_EXTERN ESDLGLBINDBUFFERPROC esdl_glBindBuffer;
+void egl_bindBuffer (sdl_data *, int, char *); 
+enum { glDeleteBuffersFunc = OPENGL_EXTS_H + 105 };
+typedef void (APIENTRY * ESDLGLDELETEBUFFERSPROC)(GLsizei n,  const GLuint * buffers);
+ESDL_EXTERN ESDLGLDELETEBUFFERSPROC esdl_glDeleteBuffers;
+void egl_deleteBuffers (sdl_data *, int, char *); 
+enum { glGenBuffersFunc = OPENGL_EXTS_H + 106 };
+typedef void (APIENTRY * ESDLGLGENBUFFERSPROC)(GLsizei n, GLuint * buffers);
+ESDL_EXTERN ESDLGLGENBUFFERSPROC esdl_glGenBuffers;
+void egl_genBuffers (sdl_data *, int, char *); 
+enum { glIsBufferFunc = OPENGL_EXTS_H + 107 };
+typedef GLboolean (APIENTRY * ESDLGLISBUFFERPROC)(GLuint buffer);
+ESDL_EXTERN ESDLGLISBUFFERPROC esdl_glIsBuffer;
+void egl_isBuffer (sdl_data *, int, char *); 
+enum { glBufferDataFunc = OPENGL_EXTS_H + 108 };
+typedef void (APIENTRY * ESDLGLBUFFERDATAPROC)(GLenum target, GLsizeiptr size,  const GLvoid * data, GLenum usage);
+ESDL_EXTERN ESDLGLBUFFERDATAPROC esdl_glBufferData;
+void egl_bufferData (sdl_data *, int, char *); 
+enum { glBufferSubDataFunc = OPENGL_EXTS_H + 109 };
+typedef void (APIENTRY * ESDLGLBUFFERSUBDATAPROC)(GLenum target, GLintptr offset, GLsizeiptr size,  const GLvoid * data);
+ESDL_EXTERN ESDLGLBUFFERSUBDATAPROC esdl_glBufferSubData;
+void egl_bufferSubData (sdl_data *, int, char *); 
+enum { glGetBufferSubDataFunc = OPENGL_EXTS_H + 110 };
+typedef void (APIENTRY * ESDLGLGETBUFFERSUBDATAPROC)(GLenum target, GLintptr offset, GLsizeiptr size, GLvoid * data);
+ESDL_EXTERN ESDLGLGETBUFFERSUBDATAPROC esdl_glGetBufferSubData;
+void egl_getBufferSubData (sdl_data *, int, char *); 
+enum { glUnmapBufferFunc = OPENGL_EXTS_H + 111 };
+typedef GLboolean (APIENTRY * ESDLGLUNMAPBUFFERPROC)(GLenum target);
+ESDL_EXTERN ESDLGLUNMAPBUFFERPROC esdl_glUnmapBuffer;
+void egl_unmapBuffer (sdl_data *, int, char *); 
+enum { glGetBufferParameterivFunc = OPENGL_EXTS_H + 112 };
+typedef void (APIENTRY * ESDLGLGETBUFFERPARAMETERIVPROC)(GLenum target, GLenum pname, GLint * params);
+ESDL_EXTERN ESDLGLGETBUFFERPARAMETERIVPROC esdl_glGetBufferParameteriv;
+void egl_getBufferParameteriv (sdl_data *, int, char *); 
+enum { glGetBufferPointervFunc = OPENGL_EXTS_H + 113 };
+typedef void (APIENTRY * ESDLGLGETBUFFERPOINTERVPROC)(GLenum target, GLenum pname,  GLvoid* *params);
+ESDL_EXTERN ESDLGLGETBUFFERPOINTERVPROC esdl_glGetBufferPointerv;
+void egl_getBufferPointerv (sdl_data *, int, char *); 
+enum { glWeightbvARBFunc = OPENGL_EXTS_H + 114 };
 typedef void (APIENTRY * ESDLGLWEIGHTBVARBPROC)(GLint size,  const GLbyte * weights);
 ESDL_EXTERN ESDLGLWEIGHTBVARBPROC esdl_glWeightbvARB;
 void egl_weightbvARB (sdl_data *, int, char *); 
-enum { glWeightsvARBFunc = OPENGL_EXTS_H + 97 };
+enum { glWeightsvARBFunc = OPENGL_EXTS_H + 115 };
 typedef void (APIENTRY * ESDLGLWEIGHTSVARBPROC)(GLint size,  const GLshort * weights);
 ESDL_EXTERN ESDLGLWEIGHTSVARBPROC esdl_glWeightsvARB;
 void egl_weightsvARB (sdl_data *, int, char *); 
-enum { glWeightivARBFunc = OPENGL_EXTS_H + 98 };
+enum { glWeightivARBFunc = OPENGL_EXTS_H + 116 };
 typedef void (APIENTRY * ESDLGLWEIGHTIVARBPROC)(GLint size,  const GLint * weights);
 ESDL_EXTERN ESDLGLWEIGHTIVARBPROC esdl_glWeightivARB;
 void egl_weightivARB (sdl_data *, int, char *); 
-enum { glWeightfvARBFunc = OPENGL_EXTS_H + 99 };
+enum { glWeightfvARBFunc = OPENGL_EXTS_H + 117 };
 typedef void (APIENTRY * ESDLGLWEIGHTFVARBPROC)(GLint size,  const GLfloat * weights);
 ESDL_EXTERN ESDLGLWEIGHTFVARBPROC esdl_glWeightfvARB;
 void egl_weightfvARB (sdl_data *, int, char *); 
-enum { glWeightdvARBFunc = OPENGL_EXTS_H + 100 };
+enum { glWeightdvARBFunc = OPENGL_EXTS_H + 118 };
 typedef void (APIENTRY * ESDLGLWEIGHTDVARBPROC)(GLint size,  const GLdouble * weights);
 ESDL_EXTERN ESDLGLWEIGHTDVARBPROC esdl_glWeightdvARB;
 void egl_weightdvARB (sdl_data *, int, char *); 
-enum { glWeightubvARBFunc = OPENGL_EXTS_H + 101 };
+enum { glWeightubvARBFunc = OPENGL_EXTS_H + 119 };
 typedef void (APIENTRY * ESDLGLWEIGHTUBVARBPROC)(GLint size,  const GLubyte * weights);
 ESDL_EXTERN ESDLGLWEIGHTUBVARBPROC esdl_glWeightubvARB;
 void egl_weightubvARB (sdl_data *, int, char *); 
-enum { glWeightusvARBFunc = OPENGL_EXTS_H + 102 };
+enum { glWeightusvARBFunc = OPENGL_EXTS_H + 120 };
 typedef void (APIENTRY * ESDLGLWEIGHTUSVARBPROC)(GLint size,  const GLushort * weights);
 ESDL_EXTERN ESDLGLWEIGHTUSVARBPROC esdl_glWeightusvARB;
 void egl_weightusvARB (sdl_data *, int, char *); 
-enum { glWeightuivARBFunc = OPENGL_EXTS_H + 103 };
+enum { glWeightuivARBFunc = OPENGL_EXTS_H + 121 };
 typedef void (APIENTRY * ESDLGLWEIGHTUIVARBPROC)(GLint size,  const GLuint * weights);
 ESDL_EXTERN ESDLGLWEIGHTUIVARBPROC esdl_glWeightuivARB;
 void egl_weightuivARB (sdl_data *, int, char *); 
-enum { glWeightPointerARBFunc = OPENGL_EXTS_H + 104 };
+enum { glWeightPointerARBFunc = OPENGL_EXTS_H + 122 };
 typedef void (APIENTRY * ESDLGLWEIGHTPOINTERARBPROC)(GLint size, GLenum type, GLsizei stride,  const GLvoid * pointer);
 ESDL_EXTERN ESDLGLWEIGHTPOINTERARBPROC esdl_glWeightPointerARB;
 void egl_weightPointerARB (sdl_data *, int, char *); 
-enum { glVertexBlendARBFunc = OPENGL_EXTS_H + 105 };
+enum { glVertexBlendARBFunc = OPENGL_EXTS_H + 123 };
 typedef void (APIENTRY * ESDLGLVERTEXBLENDARBPROC)(GLint count);
 ESDL_EXTERN ESDLGLVERTEXBLENDARBPROC esdl_glVertexBlendARB;
 void egl_vertexBlendARB (sdl_data *, int, char *); 
-enum { glCurrentPaletteMatrixARBFunc = OPENGL_EXTS_H + 106 };
+enum { glCurrentPaletteMatrixARBFunc = OPENGL_EXTS_H + 124 };
 typedef void (APIENTRY * ESDLGLCURRENTPALETTEMATRIXARBPROC)(GLint index);
 ESDL_EXTERN ESDLGLCURRENTPALETTEMATRIXARBPROC esdl_glCurrentPaletteMatrixARB;
 void egl_currentPaletteMatrixARB (sdl_data *, int, char *); 
-enum { glMatrixIndexubvARBFunc = OPENGL_EXTS_H + 107 };
+enum { glMatrixIndexubvARBFunc = OPENGL_EXTS_H + 125 };
 typedef void (APIENTRY * ESDLGLMATRIXINDEXUBVARBPROC)(GLint size,  const GLubyte * indices);
 ESDL_EXTERN ESDLGLMATRIXINDEXUBVARBPROC esdl_glMatrixIndexubvARB;
 void egl_matrixIndexubvARB (sdl_data *, int, char *); 
-enum { glMatrixIndexusvARBFunc = OPENGL_EXTS_H + 108 };
+enum { glMatrixIndexusvARBFunc = OPENGL_EXTS_H + 126 };
 typedef void (APIENTRY * ESDLGLMATRIXINDEXUSVARBPROC)(GLint size,  const GLushort * indices);
 ESDL_EXTERN ESDLGLMATRIXINDEXUSVARBPROC esdl_glMatrixIndexusvARB;
 void egl_matrixIndexusvARB (sdl_data *, int, char *); 
-enum { glMatrixIndexuivARBFunc = OPENGL_EXTS_H + 109 };
+enum { glMatrixIndexuivARBFunc = OPENGL_EXTS_H + 127 };
 typedef void (APIENTRY * ESDLGLMATRIXINDEXUIVARBPROC)(GLint size,  const GLuint * indices);
 ESDL_EXTERN ESDLGLMATRIXINDEXUIVARBPROC esdl_glMatrixIndexuivARB;
 void egl_matrixIndexuivARB (sdl_data *, int, char *); 
-enum { glMatrixIndexPointerARBFunc = OPENGL_EXTS_H + 110 };
+enum { glMatrixIndexPointerARBFunc = OPENGL_EXTS_H + 128 };
 typedef void (APIENTRY * ESDLGLMATRIXINDEXPOINTERARBPROC)(GLint size, GLenum type, GLsizei stride,  const GLvoid * pointer);
 ESDL_EXTERN ESDLGLMATRIXINDEXPOINTERARBPROC esdl_glMatrixIndexPointerARB;
 void egl_matrixIndexPointerARB (sdl_data *, int, char *); 
-enum { glVertexAttrib1dvARBFunc = OPENGL_EXTS_H + 111 };
+enum { glVertexAttrib1dvARBFunc = OPENGL_EXTS_H + 129 };
 typedef void (APIENTRY * ESDLGLVERTEXATTRIB1DVARBPROC)(GLuint index,  const GLdouble * v);
 ESDL_EXTERN ESDLGLVERTEXATTRIB1DVARBPROC esdl_glVertexAttrib1dvARB;
 void egl_vertexAttrib1dvARB (sdl_data *, int, char *); 
-enum { glVertexAttrib1fvARBFunc = OPENGL_EXTS_H + 112 };
+enum { glVertexAttrib1fvARBFunc = OPENGL_EXTS_H + 130 };
 typedef void (APIENTRY * ESDLGLVERTEXATTRIB1FVARBPROC)(GLuint index,  const GLfloat * v);
 ESDL_EXTERN ESDLGLVERTEXATTRIB1FVARBPROC esdl_glVertexAttrib1fvARB;
 void egl_vertexAttrib1fvARB (sdl_data *, int, char *); 
-enum { glVertexAttrib1svARBFunc = OPENGL_EXTS_H + 113 };
+enum { glVertexAttrib1svARBFunc = OPENGL_EXTS_H + 131 };
 typedef void (APIENTRY * ESDLGLVERTEXATTRIB1SVARBPROC)(GLuint index,  const GLshort * v);
 ESDL_EXTERN ESDLGLVERTEXATTRIB1SVARBPROC esdl_glVertexAttrib1svARB;
 void egl_vertexAttrib1svARB (sdl_data *, int, char *); 
-enum { glVertexAttrib2dvARBFunc = OPENGL_EXTS_H + 114 };
+enum { glVertexAttrib2dvARBFunc = OPENGL_EXTS_H + 132 };
 typedef void (APIENTRY * ESDLGLVERTEXATTRIB2DVARBPROC)(GLuint index,  const GLdouble * v);
 ESDL_EXTERN ESDLGLVERTEXATTRIB2DVARBPROC esdl_glVertexAttrib2dvARB;
 void egl_vertexAttrib2dvARB (sdl_data *, int, char *); 
-enum { glVertexAttrib2fvARBFunc = OPENGL_EXTS_H + 115 };
+enum { glVertexAttrib2fvARBFunc = OPENGL_EXTS_H + 133 };
 typedef void (APIENTRY * ESDLGLVERTEXATTRIB2FVARBPROC)(GLuint index,  const GLfloat * v);
 ESDL_EXTERN ESDLGLVERTEXATTRIB2FVARBPROC esdl_glVertexAttrib2fvARB;
 void egl_vertexAttrib2fvARB (sdl_data *, int, char *); 
-enum { glVertexAttrib2svARBFunc = OPENGL_EXTS_H + 116 };
+enum { glVertexAttrib2svARBFunc = OPENGL_EXTS_H + 134 };
 typedef void (APIENTRY * ESDLGLVERTEXATTRIB2SVARBPROC)(GLuint index,  const GLshort * v);
 ESDL_EXTERN ESDLGLVERTEXATTRIB2SVARBPROC esdl_glVertexAttrib2svARB;
 void egl_vertexAttrib2svARB (sdl_data *, int, char *); 
-enum { glVertexAttrib3dvARBFunc = OPENGL_EXTS_H + 117 };
+enum { glVertexAttrib3dvARBFunc = OPENGL_EXTS_H + 135 };
 typedef void (APIENTRY * ESDLGLVERTEXATTRIB3DVARBPROC)(GLuint index,  const GLdouble * v);
 ESDL_EXTERN ESDLGLVERTEXATTRIB3DVARBPROC esdl_glVertexAttrib3dvARB;
 void egl_vertexAttrib3dvARB (sdl_data *, int, char *); 
-enum { glVertexAttrib3fvARBFunc = OPENGL_EXTS_H + 118 };
+enum { glVertexAttrib3fvARBFunc = OPENGL_EXTS_H + 136 };
 typedef void (APIENTRY * ESDLGLVERTEXATTRIB3FVARBPROC)(GLuint index,  const GLfloat * v);
 ESDL_EXTERN ESDLGLVERTEXATTRIB3FVARBPROC esdl_glVertexAttrib3fvARB;
 void egl_vertexAttrib3fvARB (sdl_data *, int, char *); 
-enum { glVertexAttrib3svARBFunc = OPENGL_EXTS_H + 119 };
+enum { glVertexAttrib3svARBFunc = OPENGL_EXTS_H + 137 };
 typedef void (APIENTRY * ESDLGLVERTEXATTRIB3SVARBPROC)(GLuint index,  const GLshort * v);
 ESDL_EXTERN ESDLGLVERTEXATTRIB3SVARBPROC esdl_glVertexAttrib3svARB;
 void egl_vertexAttrib3svARB (sdl_data *, int, char *); 
-enum { glVertexAttrib4NbvARBFunc = OPENGL_EXTS_H + 120 };
+enum { glVertexAttrib4NbvARBFunc = OPENGL_EXTS_H + 138 };
 typedef void (APIENTRY * ESDLGLVERTEXATTRIB4NBVARBPROC)(GLuint index,  const GLbyte * v);
 ESDL_EXTERN ESDLGLVERTEXATTRIB4NBVARBPROC esdl_glVertexAttrib4NbvARB;
 void egl_vertexAttrib4NbvARB (sdl_data *, int, char *); 
-enum { glVertexAttrib4NivARBFunc = OPENGL_EXTS_H + 121 };
+enum { glVertexAttrib4NivARBFunc = OPENGL_EXTS_H + 139 };
 typedef void (APIENTRY * ESDLGLVERTEXATTRIB4NIVARBPROC)(GLuint index,  const GLint * v);
 ESDL_EXTERN ESDLGLVERTEXATTRIB4NIVARBPROC esdl_glVertexAttrib4NivARB;
 void egl_vertexAttrib4NivARB (sdl_data *, int, char *); 
-enum { glVertexAttrib4NsvARBFunc = OPENGL_EXTS_H + 122 };
+enum { glVertexAttrib4NsvARBFunc = OPENGL_EXTS_H + 140 };
 typedef void (APIENTRY * ESDLGLVERTEXATTRIB4NSVARBPROC)(GLuint index,  const GLshort * v);
 ESDL_EXTERN ESDLGLVERTEXATTRIB4NSVARBPROC esdl_glVertexAttrib4NsvARB;
 void egl_vertexAttrib4NsvARB (sdl_data *, int, char *); 
-enum { glVertexAttrib4NubARBFunc = OPENGL_EXTS_H + 123 };
+enum { glVertexAttrib4NubARBFunc = OPENGL_EXTS_H + 141 };
 typedef void (APIENTRY * ESDLGLVERTEXATTRIB4NUBARBPROC)(GLuint index, GLubyte x, GLubyte y, GLubyte z, GLubyte w);
 ESDL_EXTERN ESDLGLVERTEXATTRIB4NUBARBPROC esdl_glVertexAttrib4NubARB;
 void egl_vertexAttrib4NubARB (sdl_data *, int, char *); 
-enum { glVertexAttrib4NubvARBFunc = OPENGL_EXTS_H + 124 };
+enum { glVertexAttrib4NubvARBFunc = OPENGL_EXTS_H + 142 };
 typedef void (APIENTRY * ESDLGLVERTEXATTRIB4NUBVARBPROC)(GLuint index,  const GLubyte * v);
 ESDL_EXTERN ESDLGLVERTEXATTRIB4NUBVARBPROC esdl_glVertexAttrib4NubvARB;
 void egl_vertexAttrib4NubvARB (sdl_data *, int, char *); 
-enum { glVertexAttrib4NuivARBFunc = OPENGL_EXTS_H + 125 };
+enum { glVertexAttrib4NuivARBFunc = OPENGL_EXTS_H + 143 };
 typedef void (APIENTRY * ESDLGLVERTEXATTRIB4NUIVARBPROC)(GLuint index,  const GLuint * v);
 ESDL_EXTERN ESDLGLVERTEXATTRIB4NUIVARBPROC esdl_glVertexAttrib4NuivARB;
 void egl_vertexAttrib4NuivARB (sdl_data *, int, char *); 
-enum { glVertexAttrib4NusvARBFunc = OPENGL_EXTS_H + 126 };
+enum { glVertexAttrib4NusvARBFunc = OPENGL_EXTS_H + 144 };
 typedef void (APIENTRY * ESDLGLVERTEXATTRIB4NUSVARBPROC)(GLuint index,  const GLushort * v);
 ESDL_EXTERN ESDLGLVERTEXATTRIB4NUSVARBPROC esdl_glVertexAttrib4NusvARB;
 void egl_vertexAttrib4NusvARB (sdl_data *, int, char *); 
-enum { glVertexAttrib4bvARBFunc = OPENGL_EXTS_H + 127 };
+enum { glVertexAttrib4bvARBFunc = OPENGL_EXTS_H + 145 };
 typedef void (APIENTRY * ESDLGLVERTEXATTRIB4BVARBPROC)(GLuint index,  const GLbyte * v);
 ESDL_EXTERN ESDLGLVERTEXATTRIB4BVARBPROC esdl_glVertexAttrib4bvARB;
 void egl_vertexAttrib4bvARB (sdl_data *, int, char *); 
-enum { glVertexAttrib4dvARBFunc = OPENGL_EXTS_H + 128 };
+enum { glVertexAttrib4dvARBFunc = OPENGL_EXTS_H + 146 };
 typedef void (APIENTRY * ESDLGLVERTEXATTRIB4DVARBPROC)(GLuint index,  const GLdouble * v);
 ESDL_EXTERN ESDLGLVERTEXATTRIB4DVARBPROC esdl_glVertexAttrib4dvARB;
 void egl_vertexAttrib4dvARB (sdl_data *, int, char *); 
-enum { glVertexAttrib4fvARBFunc = OPENGL_EXTS_H + 129 };
+enum { glVertexAttrib4fvARBFunc = OPENGL_EXTS_H + 147 };
 typedef void (APIENTRY * ESDLGLVERTEXATTRIB4FVARBPROC)(GLuint index,  const GLfloat * v);
 ESDL_EXTERN ESDLGLVERTEXATTRIB4FVARBPROC esdl_glVertexAttrib4fvARB;
 void egl_vertexAttrib4fvARB (sdl_data *, int, char *); 
-enum { glVertexAttrib4ivARBFunc = OPENGL_EXTS_H + 130 };
+enum { glVertexAttrib4ivARBFunc = OPENGL_EXTS_H + 148 };
 typedef void (APIENTRY * ESDLGLVERTEXATTRIB4IVARBPROC)(GLuint index,  const GLint * v);
 ESDL_EXTERN ESDLGLVERTEXATTRIB4IVARBPROC esdl_glVertexAttrib4ivARB;
 void egl_vertexAttrib4ivARB (sdl_data *, int, char *); 
-enum { glVertexAttrib4svARBFunc = OPENGL_EXTS_H + 131 };
+enum { glVertexAttrib4svARBFunc = OPENGL_EXTS_H + 149 };
 typedef void (APIENTRY * ESDLGLVERTEXATTRIB4SVARBPROC)(GLuint index,  const GLshort * v);
 ESDL_EXTERN ESDLGLVERTEXATTRIB4SVARBPROC esdl_glVertexAttrib4svARB;
 void egl_vertexAttrib4svARB (sdl_data *, int, char *); 
-enum { glVertexAttrib4ubvARBFunc = OPENGL_EXTS_H + 132 };
+enum { glVertexAttrib4ubvARBFunc = OPENGL_EXTS_H + 150 };
 typedef void (APIENTRY * ESDLGLVERTEXATTRIB4UBVARBPROC)(GLuint index,  const GLubyte * v);
 ESDL_EXTERN ESDLGLVERTEXATTRIB4UBVARBPROC esdl_glVertexAttrib4ubvARB;
 void egl_vertexAttrib4ubvARB (sdl_data *, int, char *); 
-enum { glVertexAttrib4uivARBFunc = OPENGL_EXTS_H + 133 };
+enum { glVertexAttrib4uivARBFunc = OPENGL_EXTS_H + 151 };
 typedef void (APIENTRY * ESDLGLVERTEXATTRIB4UIVARBPROC)(GLuint index,  const GLuint * v);
 ESDL_EXTERN ESDLGLVERTEXATTRIB4UIVARBPROC esdl_glVertexAttrib4uivARB;
 void egl_vertexAttrib4uivARB (sdl_data *, int, char *); 
-enum { glVertexAttrib4usvARBFunc = OPENGL_EXTS_H + 134 };
+enum { glVertexAttrib4usvARBFunc = OPENGL_EXTS_H + 152 };
 typedef void (APIENTRY * ESDLGLVERTEXATTRIB4USVARBPROC)(GLuint index,  const GLushort * v);
 ESDL_EXTERN ESDLGLVERTEXATTRIB4USVARBPROC esdl_glVertexAttrib4usvARB;
 void egl_vertexAttrib4usvARB (sdl_data *, int, char *); 
-enum { glVertexAttribPointerARBFunc = OPENGL_EXTS_H + 135 };
+enum { glVertexAttribPointerARBFunc = OPENGL_EXTS_H + 153 };
 typedef void (APIENTRY * ESDLGLVERTEXATTRIBPOINTERARBPROC)(GLuint index, GLint size, GLenum type, GLboolean normalized, GLsizei stride,  const GLvoid * pointer);
 ESDL_EXTERN ESDLGLVERTEXATTRIBPOINTERARBPROC esdl_glVertexAttribPointerARB;
 void egl_vertexAttribPointerARB (sdl_data *, int, char *); 
-enum { glEnableVertexAttribArrayARBFunc = OPENGL_EXTS_H + 136 };
+enum { glEnableVertexAttribArrayARBFunc = OPENGL_EXTS_H + 154 };
 typedef void (APIENTRY * ESDLGLENABLEVERTEXATTRIBARRAYARBPROC)(GLuint index);
 ESDL_EXTERN ESDLGLENABLEVERTEXATTRIBARRAYARBPROC esdl_glEnableVertexAttribArrayARB;
 void egl_enableVertexAttribArrayARB (sdl_data *, int, char *); 
-enum { glDisableVertexAttribArrayARBFunc = OPENGL_EXTS_H + 137 };
+enum { glDisableVertexAttribArrayARBFunc = OPENGL_EXTS_H + 155 };
 typedef void (APIENTRY * ESDLGLDISABLEVERTEXATTRIBARRAYARBPROC)(GLuint index);
 ESDL_EXTERN ESDLGLDISABLEVERTEXATTRIBARRAYARBPROC esdl_glDisableVertexAttribArrayARB;
 void egl_disableVertexAttribArrayARB (sdl_data *, int, char *); 
-enum { glProgramStringARBFunc = OPENGL_EXTS_H + 138 };
+enum { glProgramStringARBFunc = OPENGL_EXTS_H + 156 };
 typedef void (APIENTRY * ESDLGLPROGRAMSTRINGARBPROC)(GLenum target, GLenum format, GLsizei len,  const GLvoid * string);
 ESDL_EXTERN ESDLGLPROGRAMSTRINGARBPROC esdl_glProgramStringARB;
 void egl_programStringARB (sdl_data *, int, char *); 
-enum { glBindProgramARBFunc = OPENGL_EXTS_H + 139 };
+enum { glBindProgramARBFunc = OPENGL_EXTS_H + 157 };
 typedef void (APIENTRY * ESDLGLBINDPROGRAMARBPROC)(GLenum target, GLuint program);
 ESDL_EXTERN ESDLGLBINDPROGRAMARBPROC esdl_glBindProgramARB;
 void egl_bindProgramARB (sdl_data *, int, char *); 
-enum { glDeleteProgramsARBFunc = OPENGL_EXTS_H + 140 };
+enum { glDeleteProgramsARBFunc = OPENGL_EXTS_H + 158 };
 typedef void (APIENTRY * ESDLGLDELETEPROGRAMSARBPROC)(GLsizei n,  const GLuint * programs);
 ESDL_EXTERN ESDLGLDELETEPROGRAMSARBPROC esdl_glDeleteProgramsARB;
 void egl_deleteProgramsARB (sdl_data *, int, char *); 
-enum { glGenProgramsARBFunc = OPENGL_EXTS_H + 141 };
+enum { glGenProgramsARBFunc = OPENGL_EXTS_H + 159 };
 typedef void (APIENTRY * ESDLGLGENPROGRAMSARBPROC)(GLsizei n, GLuint * programs);
 ESDL_EXTERN ESDLGLGENPROGRAMSARBPROC esdl_glGenProgramsARB;
 void egl_genProgramsARB (sdl_data *, int, char *); 
-enum { glProgramEnvParameter4dvARBFunc = OPENGL_EXTS_H + 142 };
+enum { glProgramEnvParameter4dvARBFunc = OPENGL_EXTS_H + 160 };
 typedef void (APIENTRY * ESDLGLPROGRAMENVPARAMETER4DVARBPROC)(GLenum target, GLuint index,  const GLdouble * params);
 ESDL_EXTERN ESDLGLPROGRAMENVPARAMETER4DVARBPROC esdl_glProgramEnvParameter4dvARB;
 void egl_programEnvParameter4dvARB (sdl_data *, int, char *); 
-enum { glProgramEnvParameter4fvARBFunc = OPENGL_EXTS_H + 143 };
+enum { glProgramEnvParameter4fvARBFunc = OPENGL_EXTS_H + 161 };
 typedef void (APIENTRY * ESDLGLPROGRAMENVPARAMETER4FVARBPROC)(GLenum target, GLuint index,  const GLfloat * params);
 ESDL_EXTERN ESDLGLPROGRAMENVPARAMETER4FVARBPROC esdl_glProgramEnvParameter4fvARB;
 void egl_programEnvParameter4fvARB (sdl_data *, int, char *); 
-enum { glProgramLocalParameter4dvARBFunc = OPENGL_EXTS_H + 144 };
+enum { glProgramLocalParameter4dvARBFunc = OPENGL_EXTS_H + 162 };
 typedef void (APIENTRY * ESDLGLPROGRAMLOCALPARAMETER4DVARBPROC)(GLenum target, GLuint index,  const GLdouble * params);
 ESDL_EXTERN ESDLGLPROGRAMLOCALPARAMETER4DVARBPROC esdl_glProgramLocalParameter4dvARB;
 void egl_programLocalParameter4dvARB (sdl_data *, int, char *); 
-enum { glProgramLocalParameter4fvARBFunc = OPENGL_EXTS_H + 145 };
+enum { glProgramLocalParameter4fvARBFunc = OPENGL_EXTS_H + 163 };
 typedef void (APIENTRY * ESDLGLPROGRAMLOCALPARAMETER4FVARBPROC)(GLenum target, GLuint index,  const GLfloat * params);
 ESDL_EXTERN ESDLGLPROGRAMLOCALPARAMETER4FVARBPROC esdl_glProgramLocalParameter4fvARB;
 void egl_programLocalParameter4fvARB (sdl_data *, int, char *); 
-enum { glGetProgramEnvParameterdvARBFunc = OPENGL_EXTS_H + 146 };
+enum { glGetProgramEnvParameterdvARBFunc = OPENGL_EXTS_H + 164 };
 typedef void (APIENTRY * ESDLGLGETPROGRAMENVPARAMETERDVARBPROC)(GLenum target, GLuint index, GLdouble * params);
 ESDL_EXTERN ESDLGLGETPROGRAMENVPARAMETERDVARBPROC esdl_glGetProgramEnvParameterdvARB;
 void egl_getProgramEnvParameterdvARB (sdl_data *, int, char *); 
-enum { glGetProgramEnvParameterfvARBFunc = OPENGL_EXTS_H + 147 };
+enum { glGetProgramEnvParameterfvARBFunc = OPENGL_EXTS_H + 165 };
 typedef void (APIENTRY * ESDLGLGETPROGRAMENVPARAMETERFVARBPROC)(GLenum target, GLuint index, GLfloat * params);
 ESDL_EXTERN ESDLGLGETPROGRAMENVPARAMETERFVARBPROC esdl_glGetProgramEnvParameterfvARB;
 void egl_getProgramEnvParameterfvARB (sdl_data *, int, char *); 
-enum { glGetProgramLocalParameterdvARBFunc = OPENGL_EXTS_H + 148 };
+enum { glGetProgramLocalParameterdvARBFunc = OPENGL_EXTS_H + 166 };
 typedef void (APIENTRY * ESDLGLGETPROGRAMLOCALPARAMETERDVARBPROC)(GLenum target, GLuint index, GLdouble * params);
 ESDL_EXTERN ESDLGLGETPROGRAMLOCALPARAMETERDVARBPROC esdl_glGetProgramLocalParameterdvARB;
 void egl_getProgramLocalParameterdvARB (sdl_data *, int, char *); 
-enum { glGetProgramLocalParameterfvARBFunc = OPENGL_EXTS_H + 149 };
+enum { glGetProgramLocalParameterfvARBFunc = OPENGL_EXTS_H + 167 };
 typedef void (APIENTRY * ESDLGLGETPROGRAMLOCALPARAMETERFVARBPROC)(GLenum target, GLuint index, GLfloat * params);
 ESDL_EXTERN ESDLGLGETPROGRAMLOCALPARAMETERFVARBPROC esdl_glGetProgramLocalParameterfvARB;
 void egl_getProgramLocalParameterfvARB (sdl_data *, int, char *); 
-enum { glGetProgramivARBFunc = OPENGL_EXTS_H + 150 };
+enum { glGetProgramivARBFunc = OPENGL_EXTS_H + 168 };
 typedef void (APIENTRY * ESDLGLGETPROGRAMIVARBPROC)(GLenum target, GLenum pname, GLint * params);
 ESDL_EXTERN ESDLGLGETPROGRAMIVARBPROC esdl_glGetProgramivARB;
 void egl_getProgramivARB (sdl_data *, int, char *); 
-enum { glGetProgramStringARBFunc = OPENGL_EXTS_H + 151 };
+enum { glGetProgramStringARBFunc = OPENGL_EXTS_H + 169 };
 typedef void (APIENTRY * ESDLGLGETPROGRAMSTRINGARBPROC)(GLenum target, GLenum pname, GLvoid * string);
 ESDL_EXTERN ESDLGLGETPROGRAMSTRINGARBPROC esdl_glGetProgramStringARB;
 void egl_getProgramStringARB (sdl_data *, int, char *); 
-enum { glGetVertexAttribdvARBFunc = OPENGL_EXTS_H + 152 };
+enum { glGetVertexAttribdvARBFunc = OPENGL_EXTS_H + 170 };
 typedef void (APIENTRY * ESDLGLGETVERTEXATTRIBDVARBPROC)(GLuint index, GLenum pname, GLdouble * params);
 ESDL_EXTERN ESDLGLGETVERTEXATTRIBDVARBPROC esdl_glGetVertexAttribdvARB;
 void egl_getVertexAttribdvARB (sdl_data *, int, char *); 
-enum { glGetVertexAttribfvARBFunc = OPENGL_EXTS_H + 153 };
+enum { glGetVertexAttribfvARBFunc = OPENGL_EXTS_H + 171 };
 typedef void (APIENTRY * ESDLGLGETVERTEXATTRIBFVARBPROC)(GLuint index, GLenum pname, GLfloat * params);
 ESDL_EXTERN ESDLGLGETVERTEXATTRIBFVARBPROC esdl_glGetVertexAttribfvARB;
 void egl_getVertexAttribfvARB (sdl_data *, int, char *); 
-enum { glGetVertexAttribivARBFunc = OPENGL_EXTS_H + 154 };
+enum { glGetVertexAttribivARBFunc = OPENGL_EXTS_H + 172 };
 typedef void (APIENTRY * ESDLGLGETVERTEXATTRIBIVARBPROC)(GLuint index, GLenum pname, GLint * params);
 ESDL_EXTERN ESDLGLGETVERTEXATTRIBIVARBPROC esdl_glGetVertexAttribivARB;
 void egl_getVertexAttribivARB (sdl_data *, int, char *); 
-enum { glGetVertexAttribPointervARBFunc = OPENGL_EXTS_H + 155 };
+enum { glGetVertexAttribPointervARBFunc = OPENGL_EXTS_H + 173 };
 typedef void (APIENTRY * ESDLGLGETVERTEXATTRIBPOINTERVARBPROC)(GLuint index, GLenum pname,  GLvoid* *pointer);
 ESDL_EXTERN ESDLGLGETVERTEXATTRIBPOINTERVARBPROC esdl_glGetVertexAttribPointervARB;
 void egl_getVertexAttribPointervARB (sdl_data *, int, char *); 
-enum { glIsProgramARBFunc = OPENGL_EXTS_H + 156 };
+enum { glIsProgramARBFunc = OPENGL_EXTS_H + 174 };
 typedef GLboolean (APIENTRY * ESDLGLISPROGRAMARBPROC)(GLuint program);
 ESDL_EXTERN ESDLGLISPROGRAMARBPROC esdl_glIsProgramARB;
 void egl_isProgramARB (sdl_data *, int, char *); 
+enum { glDeleteObjectARBFunc = OPENGL_EXTS_H + 175 };
+typedef void (APIENTRY * ESDLGLDELETEOBJECTARBPROC)(GLhandleARB obj);
+ESDL_EXTERN ESDLGLDELETEOBJECTARBPROC esdl_glDeleteObjectARB;
+void egl_deleteObjectARB (sdl_data *, int, char *); 
+enum { glGetHandleARBFunc = OPENGL_EXTS_H + 176 };
+typedef GLhandleARB (APIENTRY * ESDLGLGETHANDLEARBPROC)(GLenum pname);
+ESDL_EXTERN ESDLGLGETHANDLEARBPROC esdl_glGetHandleARB;
+void egl_getHandleARB (sdl_data *, int, char *); 
+enum { glDetachObjectARBFunc = OPENGL_EXTS_H + 177 };
+typedef void (APIENTRY * ESDLGLDETACHOBJECTARBPROC)(GLhandleARB containerObj, GLhandleARB attachedObj);
+ESDL_EXTERN ESDLGLDETACHOBJECTARBPROC esdl_glDetachObjectARB;
+void egl_detachObjectARB (sdl_data *, int, char *); 
+enum { glCreateShaderObjectARBFunc = OPENGL_EXTS_H + 178 };
+typedef GLhandleARB (APIENTRY * ESDLGLCREATESHADEROBJECTARBPROC)(GLenum shaderType);
+ESDL_EXTERN ESDLGLCREATESHADEROBJECTARBPROC esdl_glCreateShaderObjectARB;
+void egl_createShaderObjectARB (sdl_data *, int, char *); 
+enum { glShaderSourceARBFunc = OPENGL_EXTS_H + 179 };
+typedef void (APIENTRY * ESDLGLSHADERSOURCEARBPROC)(GLhandleARB shaderObj, GLsizei count,  const GLcharARB* *string,  const GLint * length);
+ESDL_EXTERN ESDLGLSHADERSOURCEARBPROC esdl_glShaderSourceARB;
+void egl_shaderSourceARB (sdl_data *, int, char *); 
+enum { glCompileShaderARBFunc = OPENGL_EXTS_H + 180 };
+typedef void (APIENTRY * ESDLGLCOMPILESHADERARBPROC)(GLhandleARB shaderObj);
+ESDL_EXTERN ESDLGLCOMPILESHADERARBPROC esdl_glCompileShaderARB;
+void egl_compileShaderARB (sdl_data *, int, char *); 
+enum { glCreateProgramObjectARBFunc = OPENGL_EXTS_H + 181 };
+typedef GLhandleARB (APIENTRY * ESDLGLCREATEPROGRAMOBJECTARBPROC)();
+ESDL_EXTERN ESDLGLCREATEPROGRAMOBJECTARBPROC esdl_glCreateProgramObjectARB;
+void egl_createProgramObjectARB (sdl_data *, int, char *); 
+enum { glAttachObjectARBFunc = OPENGL_EXTS_H + 182 };
+typedef void (APIENTRY * ESDLGLATTACHOBJECTARBPROC)(GLhandleARB containerObj, GLhandleARB obj);
+ESDL_EXTERN ESDLGLATTACHOBJECTARBPROC esdl_glAttachObjectARB;
+void egl_attachObjectARB (sdl_data *, int, char *); 
+enum { glLinkProgramARBFunc = OPENGL_EXTS_H + 183 };
+typedef void (APIENTRY * ESDLGLLINKPROGRAMARBPROC)(GLhandleARB programObj);
+ESDL_EXTERN ESDLGLLINKPROGRAMARBPROC esdl_glLinkProgramARB;
+void egl_linkProgramARB (sdl_data *, int, char *); 
+enum { glUseProgramObjectARBFunc = OPENGL_EXTS_H + 184 };
+typedef void (APIENTRY * ESDLGLUSEPROGRAMOBJECTARBPROC)(GLhandleARB programObj);
+ESDL_EXTERN ESDLGLUSEPROGRAMOBJECTARBPROC esdl_glUseProgramObjectARB;
+void egl_useProgramObjectARB (sdl_data *, int, char *); 
+enum { glValidateProgramARBFunc = OPENGL_EXTS_H + 185 };
+typedef void (APIENTRY * ESDLGLVALIDATEPROGRAMARBPROC)(GLhandleARB programObj);
+ESDL_EXTERN ESDLGLVALIDATEPROGRAMARBPROC esdl_glValidateProgramARB;
+void egl_validateProgramARB (sdl_data *, int, char *); 
+enum { glUniform1fvARBFunc = OPENGL_EXTS_H + 186 };
+typedef void (APIENTRY * ESDLGLUNIFORM1FVARBPROC)(GLint location, GLsizei count,  const GLfloat * value);
+ESDL_EXTERN ESDLGLUNIFORM1FVARBPROC esdl_glUniform1fvARB;
+void egl_uniform1fvARB (sdl_data *, int, char *); 
+enum { glUniform2fvARBFunc = OPENGL_EXTS_H + 187 };
+typedef void (APIENTRY * ESDLGLUNIFORM2FVARBPROC)(GLint location, GLsizei count,  const GLfloat * value);
+ESDL_EXTERN ESDLGLUNIFORM2FVARBPROC esdl_glUniform2fvARB;
+void egl_uniform2fvARB (sdl_data *, int, char *); 
+enum { glUniform3fvARBFunc = OPENGL_EXTS_H + 188 };
+typedef void (APIENTRY * ESDLGLUNIFORM3FVARBPROC)(GLint location, GLsizei count,  const GLfloat * value);
+ESDL_EXTERN ESDLGLUNIFORM3FVARBPROC esdl_glUniform3fvARB;
+void egl_uniform3fvARB (sdl_data *, int, char *); 
+enum { glUniform4fvARBFunc = OPENGL_EXTS_H + 189 };
+typedef void (APIENTRY * ESDLGLUNIFORM4FVARBPROC)(GLint location, GLsizei count,  const GLfloat * value);
+ESDL_EXTERN ESDLGLUNIFORM4FVARBPROC esdl_glUniform4fvARB;
+void egl_uniform4fvARB (sdl_data *, int, char *); 
+enum { glUniform1ivARBFunc = OPENGL_EXTS_H + 190 };
+typedef void (APIENTRY * ESDLGLUNIFORM1IVARBPROC)(GLint location, GLsizei count,  const GLint * value);
+ESDL_EXTERN ESDLGLUNIFORM1IVARBPROC esdl_glUniform1ivARB;
+void egl_uniform1ivARB (sdl_data *, int, char *); 
+enum { glUniform2ivARBFunc = OPENGL_EXTS_H + 191 };
+typedef void (APIENTRY * ESDLGLUNIFORM2IVARBPROC)(GLint location, GLsizei count,  const GLint * value);
+ESDL_EXTERN ESDLGLUNIFORM2IVARBPROC esdl_glUniform2ivARB;
+void egl_uniform2ivARB (sdl_data *, int, char *); 
+enum { glUniform3ivARBFunc = OPENGL_EXTS_H + 192 };
+typedef void (APIENTRY * ESDLGLUNIFORM3IVARBPROC)(GLint location, GLsizei count,  const GLint * value);
+ESDL_EXTERN ESDLGLUNIFORM3IVARBPROC esdl_glUniform3ivARB;
+void egl_uniform3ivARB (sdl_data *, int, char *); 
+enum { glUniform4ivARBFunc = OPENGL_EXTS_H + 193 };
+typedef void (APIENTRY * ESDLGLUNIFORM4IVARBPROC)(GLint location, GLsizei count,  const GLint * value);
+ESDL_EXTERN ESDLGLUNIFORM4IVARBPROC esdl_glUniform4ivARB;
+void egl_uniform4ivARB (sdl_data *, int, char *); 
+enum { glUniformMatrix2fvARBFunc = OPENGL_EXTS_H + 194 };
+typedef void (APIENTRY * ESDLGLUNIFORMMATRIX2FVARBPROC)(GLint location, GLsizei count, GLboolean transpose,  const GLfloat * value);
+ESDL_EXTERN ESDLGLUNIFORMMATRIX2FVARBPROC esdl_glUniformMatrix2fvARB;
+void egl_uniformMatrix2fvARB (sdl_data *, int, char *); 
+enum { glUniformMatrix3fvARBFunc = OPENGL_EXTS_H + 195 };
+typedef void (APIENTRY * ESDLGLUNIFORMMATRIX3FVARBPROC)(GLint location, GLsizei count, GLboolean transpose,  const GLfloat * value);
+ESDL_EXTERN ESDLGLUNIFORMMATRIX3FVARBPROC esdl_glUniformMatrix3fvARB;
+void egl_uniformMatrix3fvARB (sdl_data *, int, char *); 
+enum { glUniformMatrix4fvARBFunc = OPENGL_EXTS_H + 196 };
+typedef void (APIENTRY * ESDLGLUNIFORMMATRIX4FVARBPROC)(GLint location, GLsizei count, GLboolean transpose,  const GLfloat * value);
+ESDL_EXTERN ESDLGLUNIFORMMATRIX4FVARBPROC esdl_glUniformMatrix4fvARB;
+void egl_uniformMatrix4fvARB (sdl_data *, int, char *); 
+enum { glGetObjectParameterfvARBFunc = OPENGL_EXTS_H + 197 };
+typedef void (APIENTRY * ESDLGLGETOBJECTPARAMETERFVARBPROC)(GLhandleARB obj, GLenum pname, GLfloat * params);
+ESDL_EXTERN ESDLGLGETOBJECTPARAMETERFVARBPROC esdl_glGetObjectParameterfvARB;
+void egl_getObjectParameterfvARB (sdl_data *, int, char *); 
+enum { glGetObjectParameterivARBFunc = OPENGL_EXTS_H + 198 };
+typedef void (APIENTRY * ESDLGLGETOBJECTPARAMETERIVARBPROC)(GLhandleARB obj, GLenum pname, GLint * params);
+ESDL_EXTERN ESDLGLGETOBJECTPARAMETERIVARBPROC esdl_glGetObjectParameterivARB;
+void egl_getObjectParameterivARB (sdl_data *, int, char *); 
+enum { glGetInfoLogARBFunc = OPENGL_EXTS_H + 199 };
+typedef void (APIENTRY * ESDLGLGETINFOLOGARBPROC)(GLhandleARB obj, GLsizei maxLength, GLsizei * length, GLcharARB * infoLog);
+ESDL_EXTERN ESDLGLGETINFOLOGARBPROC esdl_glGetInfoLogARB;
+void egl_getInfoLogARB (sdl_data *, int, char *); 
+enum { glGetAttachedObjectsARBFunc = OPENGL_EXTS_H + 200 };
+typedef void (APIENTRY * ESDLGLGETATTACHEDOBJECTSARBPROC)(GLhandleARB containerObj, GLsizei maxCount, GLsizei * count, GLhandleARB * obj);
+ESDL_EXTERN ESDLGLGETATTACHEDOBJECTSARBPROC esdl_glGetAttachedObjectsARB;
+void egl_getAttachedObjectsARB (sdl_data *, int, char *); 
+enum { glGetUniformLocationARBFunc = OPENGL_EXTS_H + 201 };
+typedef GLint (APIENTRY * ESDLGLGETUNIFORMLOCATIONARBPROC)(GLhandleARB programObj,  const GLcharARB * name);
+ESDL_EXTERN ESDLGLGETUNIFORMLOCATIONARBPROC esdl_glGetUniformLocationARB;
+void egl_getUniformLocationARB (sdl_data *, int, char *); 
+enum { glGetActiveUniformARBFunc = OPENGL_EXTS_H + 202 };
+typedef void (APIENTRY * ESDLGLGETACTIVEUNIFORMARBPROC)(GLhandleARB programObj, GLuint index, GLsizei maxLength, GLsizei * length, GLint * size, GLenum * type, GLcharARB * name);
+ESDL_EXTERN ESDLGLGETACTIVEUNIFORMARBPROC esdl_glGetActiveUniformARB;
+void egl_getActiveUniformARB (sdl_data *, int, char *); 
+enum { glGetUniformfvARBFunc = OPENGL_EXTS_H + 203 };
+typedef void (APIENTRY * ESDLGLGETUNIFORMFVARBPROC)(GLhandleARB programObj, GLint location, GLfloat * params);
+ESDL_EXTERN ESDLGLGETUNIFORMFVARBPROC esdl_glGetUniformfvARB;
+void egl_getUniformfvARB (sdl_data *, int, char *); 
+enum { glGetUniformivARBFunc = OPENGL_EXTS_H + 204 };
+typedef void (APIENTRY * ESDLGLGETUNIFORMIVARBPROC)(GLhandleARB programObj, GLint location, GLint * params);
+ESDL_EXTERN ESDLGLGETUNIFORMIVARBPROC esdl_glGetUniformivARB;
+void egl_getUniformivARB (sdl_data *, int, char *); 
+enum { glGetShaderSourceARBFunc = OPENGL_EXTS_H + 205 };
+typedef void (APIENTRY * ESDLGLGETSHADERSOURCEARBPROC)(GLhandleARB obj, GLsizei maxLength, GLsizei * length, GLcharARB * source);
+ESDL_EXTERN ESDLGLGETSHADERSOURCEARBPROC esdl_glGetShaderSourceARB;
+void egl_getShaderSourceARB (sdl_data *, int, char *); 
+enum { glBindAttribLocationARBFunc = OPENGL_EXTS_H + 206 };
+typedef void (APIENTRY * ESDLGLBINDATTRIBLOCATIONARBPROC)(GLhandleARB programObj, GLuint index,  const GLcharARB * name);
+ESDL_EXTERN ESDLGLBINDATTRIBLOCATIONARBPROC esdl_glBindAttribLocationARB;
+void egl_bindAttribLocationARB (sdl_data *, int, char *); 
+enum { glGetActiveAttribARBFunc = OPENGL_EXTS_H + 207 };
+typedef void (APIENTRY * ESDLGLGETACTIVEATTRIBARBPROC)(GLhandleARB programObj, GLuint index, GLsizei maxLength, GLsizei * length, GLint * size, GLenum * type, GLcharARB * name);
+ESDL_EXTERN ESDLGLGETACTIVEATTRIBARBPROC esdl_glGetActiveAttribARB;
+void egl_getActiveAttribARB (sdl_data *, int, char *); 
+enum { glGetAttribLocationARBFunc = OPENGL_EXTS_H + 208 };
+typedef GLint (APIENTRY * ESDLGLGETATTRIBLOCATIONARBPROC)(GLhandleARB programObj,  const GLcharARB * name);
+ESDL_EXTERN ESDLGLGETATTRIBLOCATIONARBPROC esdl_glGetAttribLocationARB;
+void egl_getAttribLocationARB (sdl_data *, int, char *); 
+enum { glStencilOpSeparateATIFunc = OPENGL_EXTS_H + 209 };
+typedef void (APIENTRY * ESDLGLSTENCILOPSEPARATEATIPROC)(GLenum face, GLenum sfail, GLenum dpfail, GLenum dppass);
+ESDL_EXTERN ESDLGLSTENCILOPSEPARATEATIPROC esdl_glStencilOpSeparateATI;
+void egl_stencilOpSeparateATI (sdl_data *, int, char *); 
+enum { glStencilFuncSeparateATIFunc = OPENGL_EXTS_H + 210 };
+typedef void (APIENTRY * ESDLGLSTENCILFUNCSEPARATEATIPROC)(GLenum frontfunc, GLenum backfunc, GLint ref, GLuint mask);
+ESDL_EXTERN ESDLGLSTENCILFUNCSEPARATEATIPROC esdl_glStencilFuncSeparateATI;
+void egl_stencilFuncSeparateATI (sdl_data *, int, char *); 
