@@ -3,7 +3,7 @@
  *  See the file "license.terms" for information on usage and redistribution
  *  of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- *     $Id: esdl_glext_fp.h,v 1.1 2003/08/29 13:31:47 dgud Exp $
+ *     $Id: esdl_glext_fp.h,v 1.2 2004/03/31 14:00:15 dgud Exp $
  *
  */
 { glBlendColorFunc,  "glBlendColor", egl_blendColor, &esdl_glBlendColor},
@@ -102,6 +102,24 @@
 { glWindowPos3fvFunc,  "glWindowPos3fv", egl_windowPos3fv, &esdl_glWindowPos3fv},
 { glWindowPos3ivFunc,  "glWindowPos3iv", egl_windowPos3iv, &esdl_glWindowPos3iv},
 { glWindowPos3svFunc,  "glWindowPos3sv", egl_windowPos3sv, &esdl_glWindowPos3sv},
+{ glGenQueriesFunc,  "glGenQueries", egl_genQueries, &esdl_glGenQueries},
+{ glDeleteQueriesFunc,  "glDeleteQueries", egl_deleteQueries, &esdl_glDeleteQueries},
+{ glIsQueryFunc,  "glIsQuery", egl_isQuery, &esdl_glIsQuery},
+{ glBeginQueryFunc,  "glBeginQuery", egl_beginQuery, &esdl_glBeginQuery},
+{ glEndQueryFunc,  "glEndQuery", egl_endQuery, &esdl_glEndQuery},
+{ glGetQueryivFunc,  "glGetQueryiv", egl_getQueryiv, &esdl_glGetQueryiv},
+{ glGetQueryObjectivFunc,  "glGetQueryObjectiv", egl_getQueryObjectiv, &esdl_glGetQueryObjectiv},
+{ glGetQueryObjectuivFunc,  "glGetQueryObjectuiv", egl_getQueryObjectuiv, &esdl_glGetQueryObjectuiv},
+{ glBindBufferFunc,  "glBindBuffer", egl_bindBuffer, &esdl_glBindBuffer},
+{ glDeleteBuffersFunc,  "glDeleteBuffers", egl_deleteBuffers, &esdl_glDeleteBuffers},
+{ glGenBuffersFunc,  "glGenBuffers", egl_genBuffers, &esdl_glGenBuffers},
+{ glIsBufferFunc,  "glIsBuffer", egl_isBuffer, &esdl_glIsBuffer},
+{ glBufferDataFunc,  "glBufferData", egl_bufferData, &esdl_glBufferData},
+{ glBufferSubDataFunc,  "glBufferSubData", egl_bufferSubData, &esdl_glBufferSubData},
+{ glGetBufferSubDataFunc,  "glGetBufferSubData", egl_getBufferSubData, &esdl_glGetBufferSubData},
+{ glUnmapBufferFunc,  "glUnmapBuffer", egl_unmapBuffer, &esdl_glUnmapBuffer},
+{ glGetBufferParameterivFunc,  "glGetBufferParameteriv", egl_getBufferParameteriv, &esdl_glGetBufferParameteriv},
+{ glGetBufferPointervFunc,  "glGetBufferPointerv", egl_getBufferPointerv, &esdl_glGetBufferPointerv},
 { glWeightbvARBFunc,  "glWeightbvARB", egl_weightbvARB, &esdl_glWeightbvARB},
 { glWeightsvARBFunc,  "glWeightsvARB", egl_weightsvARB, &esdl_glWeightsvARB},
 { glWeightivARBFunc,  "glWeightivARB", egl_weightivARB, &esdl_glWeightivARB},
@@ -163,3 +181,39 @@
 { glGetVertexAttribivARBFunc,  "glGetVertexAttribivARB", egl_getVertexAttribivARB, &esdl_glGetVertexAttribivARB},
 { glGetVertexAttribPointervARBFunc,  "glGetVertexAttribPointervARB", egl_getVertexAttribPointervARB, &esdl_glGetVertexAttribPointervARB},
 { glIsProgramARBFunc,  "glIsProgramARB", egl_isProgramARB, &esdl_glIsProgramARB},
+{ glDeleteObjectARBFunc,  "glDeleteObjectARB", egl_deleteObjectARB, &esdl_glDeleteObjectARB},
+{ glGetHandleARBFunc,  "glGetHandleARB", egl_getHandleARB, &esdl_glGetHandleARB},
+{ glDetachObjectARBFunc,  "glDetachObjectARB", egl_detachObjectARB, &esdl_glDetachObjectARB},
+{ glCreateShaderObjectARBFunc,  "glCreateShaderObjectARB", egl_createShaderObjectARB, &esdl_glCreateShaderObjectARB},
+{ glShaderSourceARBFunc,  "glShaderSourceARB", egl_shaderSourceARB, &esdl_glShaderSourceARB},
+{ glCompileShaderARBFunc,  "glCompileShaderARB", egl_compileShaderARB, &esdl_glCompileShaderARB},
+{ glCreateProgramObjectARBFunc,  "glCreateProgramObjectARB", egl_createProgramObjectARB, &esdl_glCreateProgramObjectARB},
+{ glAttachObjectARBFunc,  "glAttachObjectARB", egl_attachObjectARB, &esdl_glAttachObjectARB},
+{ glLinkProgramARBFunc,  "glLinkProgramARB", egl_linkProgramARB, &esdl_glLinkProgramARB},
+{ glUseProgramObjectARBFunc,  "glUseProgramObjectARB", egl_useProgramObjectARB, &esdl_glUseProgramObjectARB},
+{ glValidateProgramARBFunc,  "glValidateProgramARB", egl_validateProgramARB, &esdl_glValidateProgramARB},
+{ glUniform1fvARBFunc,  "glUniform1fvARB", egl_uniform1fvARB, &esdl_glUniform1fvARB},
+{ glUniform2fvARBFunc,  "glUniform2fvARB", egl_uniform2fvARB, &esdl_glUniform2fvARB},
+{ glUniform3fvARBFunc,  "glUniform3fvARB", egl_uniform3fvARB, &esdl_glUniform3fvARB},
+{ glUniform4fvARBFunc,  "glUniform4fvARB", egl_uniform4fvARB, &esdl_glUniform4fvARB},
+{ glUniform1ivARBFunc,  "glUniform1ivARB", egl_uniform1ivARB, &esdl_glUniform1ivARB},
+{ glUniform2ivARBFunc,  "glUniform2ivARB", egl_uniform2ivARB, &esdl_glUniform2ivARB},
+{ glUniform3ivARBFunc,  "glUniform3ivARB", egl_uniform3ivARB, &esdl_glUniform3ivARB},
+{ glUniform4ivARBFunc,  "glUniform4ivARB", egl_uniform4ivARB, &esdl_glUniform4ivARB},
+{ glUniformMatrix2fvARBFunc,  "glUniformMatrix2fvARB", egl_uniformMatrix2fvARB, &esdl_glUniformMatrix2fvARB},
+{ glUniformMatrix3fvARBFunc,  "glUniformMatrix3fvARB", egl_uniformMatrix3fvARB, &esdl_glUniformMatrix3fvARB},
+{ glUniformMatrix4fvARBFunc,  "glUniformMatrix4fvARB", egl_uniformMatrix4fvARB, &esdl_glUniformMatrix4fvARB},
+{ glGetObjectParameterfvARBFunc,  "glGetObjectParameterfvARB", egl_getObjectParameterfvARB, &esdl_glGetObjectParameterfvARB},
+{ glGetObjectParameterivARBFunc,  "glGetObjectParameterivARB", egl_getObjectParameterivARB, &esdl_glGetObjectParameterivARB},
+{ glGetInfoLogARBFunc,  "glGetInfoLogARB", egl_getInfoLogARB, &esdl_glGetInfoLogARB},
+{ glGetAttachedObjectsARBFunc,  "glGetAttachedObjectsARB", egl_getAttachedObjectsARB, &esdl_glGetAttachedObjectsARB},
+{ glGetUniformLocationARBFunc,  "glGetUniformLocationARB", egl_getUniformLocationARB, &esdl_glGetUniformLocationARB},
+{ glGetActiveUniformARBFunc,  "glGetActiveUniformARB", egl_getActiveUniformARB, &esdl_glGetActiveUniformARB},
+{ glGetUniformfvARBFunc,  "glGetUniformfvARB", egl_getUniformfvARB, &esdl_glGetUniformfvARB},
+{ glGetUniformivARBFunc,  "glGetUniformivARB", egl_getUniformivARB, &esdl_glGetUniformivARB},
+{ glGetShaderSourceARBFunc,  "glGetShaderSourceARB", egl_getShaderSourceARB, &esdl_glGetShaderSourceARB},
+{ glBindAttribLocationARBFunc,  "glBindAttribLocationARB", egl_bindAttribLocationARB, &esdl_glBindAttribLocationARB},
+{ glGetActiveAttribARBFunc,  "glGetActiveAttribARB", egl_getActiveAttribARB, &esdl_glGetActiveAttribARB},
+{ glGetAttribLocationARBFunc,  "glGetAttribLocationARB", egl_getAttribLocationARB, &esdl_glGetAttribLocationARB},
+{ glStencilOpSeparateATIFunc,  "glStencilOpSeparateATI", egl_stencilOpSeparateATI, &esdl_glStencilOpSeparateATI},
+{ glStencilFuncSeparateATIFunc,  "glStencilFuncSeparateATI", egl_stencilFuncSeparateATI, &esdl_glStencilFuncSeparateATI},
