@@ -3,7 +3,7 @@
  *  See the file "license.terms" for information on usage and redistribution
  *  of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- *     $Id: esdl_glu.c,v 1.36 2003/05/24 12:45:41 bjorng Exp $
+ *     $Id: esdl_glu.c,v 1.2 2004/04/10 15:38:55 bufflig Exp $
  *
  *  
  *  GLU wrapper 
@@ -14,7 +14,11 @@
 #include <stdlib.h>  /* malloc */
 #include <string.h>  /* malloc */
 #include <math.h>  /* malloc */
+#ifdef FLAVOUR_WOGGLE
+#include <woggle_driver.h>
+#else
 #include "esdl.h"
+#endif
 #ifdef _OSX_COCOA
 #include <OpenGL/glu.h>
 #else
